@@ -3,9 +3,10 @@
 #include "IncludeDefine.h"
 #include "Parameters.h"
 #include "Genome.h"
+#include "Solo.h"
 
 #include SAMTOOLS_BGZF_H
 
-void BAMbinSortByCoordinate(uint32 iBin, uint binN, uint binS, uint nThreads, string dirBAMsort, Parameters &P, Genome &mapGen);
+void BAMbinSortByCoordinate(uint32 iBin, uint binN, uint binS, uint nThreads, string dirBAMsort, Parameters &P, Genome &mapGen, Solo &solo);
 
 #endif
\ No newline at end of file
