@@ -3,9 +3,10 @@
 #include "IncludeDefine.h"
 #include "Parameters.h"
 #include "Genome.h"
+#include "Solo.h"
 
 #include SAMTOOLS_BGZF_H
 
-void BAMbinSortUnmapped(uint32 iBin, uint nThreads, string dirBAMsort, Parameters &P, Genome &mapGen);
+void BAMbinSortUnmapped(uint32 iBin, uint nThreads, string dirBAMsort, Parameters &P, Genome &genome, Solo &solo);
 
 #endif
