@@ -1,10 +1,13 @@
 #include "ReadAlignChunk.h"
-#include "GlobalVariables.h"
 #include "ThreadControl.h"
 #include "ErrorWarning.h"
 #include "SequenceFuns.h"
 #include "GlobalVariables.h"
 
+inline uint64 fastqReadOneLine(ifstream &streamIn, char *arrIn);
+inline void removeStringEndControl(string &str);
+
+
 void ReadAlignChunk::processChunks() {//read-map-write chunks
     noReadsLeft=false; //true if there no more reads left in the file
     bool newFile=false; //new file marker in the input stream
@@ -14,37 +17,64 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
 
             if (P.runThreadN>1) pthread_mutex_lock(&g_threadChunks.mutexInRead);
 
-            uint chunkInSizeBytesTotal[2]={0,0};
+            chunkInSizeBytesTotal={0,0};
+            
             while (chunkInSizeBytesTotal[0] < P.chunkInSizeBytes && chunkInSizeBytesTotal[1] < P.chunkInSizeBytes && P.inOut->readIn[0].good() && P.inOut->readIn[1].good()) {
                 char nextChar=P.inOut->readIn[0].peek();
                 if (P.iReadAll==P.readMapNumber) {//do not read any more reads
                     break;
+                    
+                ///////////////////////////////////////////////////////////////////////////////////// SAM                        
                 } else if (P.readFilesTypeN==10 && P.inOut->readIn[0].good() && P.outFilterBySJoutStage!=2) {//SAM input && not eof && not 2nd stage
 
-                    string str1;
 
                     if (nextChar=='@') {//with SAM input linest that start with @ are headers
-                        getline(P.inOut->readIn[0], str1); //read line and skip it
+                        P.inOut->readIn[0].ignore(DEF_readNameSeqLengthMax,'\n'); //read line and skip it
                         continue;
                     };
 
+                    string str1;
                     P.inOut->readIn[0] >> str1;
                     if (str1=="FILE") {
                         newFile=true;
                     } else {
                         P.iReadAll++; //increment read number
 
+                        uint64 flag1; 
+                        P.inOut->readIn[0] >> flag1;
                         uint imate1=0;
-                        for (uint imate=0;imate<P.readNmates;imate++) {
-                            if (imate>0)
-                                P.inOut->readIn[0] >> str1; //for imate=0 str1 was already read
-                            uint flag;
-                            P.inOut->readIn[0] >>flag; //read name and flag
-                            char passFilterIllumina=(flag & 0x800 ? 'Y' : 'N');
+                        for (uint imate=0;imate<P.readNmates;imate++) {//not readNends: this is SAM input
+                            if (imate>0) {
+                                string str2;
+                                uint64 flag2;
+                                P.inOut->readIn[0] >> str2; //for imate=0 str1 was already read
+                                P.inOut->readIn[0] >> flag2; //read name and flag
+                                
+                                if ( str1 != str2 ) {
+                                    ostringstream errOut;
+                                    errOut << ERROR_OUT <<" EXITING because of FATAL ERROR in input BAM file: the consecutive lines in paired-end BAM have different read IDs:\n"
+                                           << str1 <<"   vs   "<< str2 << '\n'
+                                           << "\n SOLUTION: fix BAM file formatting. Paired-end reads should be always consecutive lines, with exactly 2 lines per paired-end read" ;
+                                    exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_INPUT_FILES, P);
+                                };
+                                
+                                if (! ( ((flag1 & 0x40) && (flag2 & 0x80)) || ((flag2 & 0x40) && (flag1 & 0x80)) ) ) {
+                                    ostringstream errOut;
+                                    errOut << ERROR_OUT <<" EXITING because of FATAL ERROR in input BAM file: the consecutive lines in paired-end BAM have wrong mate FLAG bits:\n"
+                                           << str1 <<"   "<< flag1 <<"   vs   "<< str2 <<"   "<< flag2 << '\n'
+                                           << "\n SOLUTION: fix BAM file formatting. Paired-end reads should be always consecutive lines, with exactly 2 lines per paired-end read."
+                                           << " Mate1 should have 0x40 bit set in the FLAG, Mate2 should have 0x80 bit set in the FLAG";
+                                    exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_INPUT_FILES, P);
+                                };
+                                
+                                str1 = str2;   //used below for both mates
+                                flag1 = flag2; //used below for both mates
+                            };
+                            char passFilterIllumina=(flag1 & 0x800 ? 'Y' : 'N');
 
                             if (imate==1) {//2nd line is always opposite of the 1st one
                                 imate1=1-imate1;
-                            } else if (P.readNmates==2 && (flag & 0x80)) {
+                            } else if (P.readNmates==2 && (flag1 & 0x80)) {//not readNends: this is SAM input
                                 imate1=1;
                             } else {
                                 imate1=0;
@@ -60,25 +90,30 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
                             //iReadAll, passFilterIllumina, passFilterIllumina
                             chunkInSizeBytesTotal[imate1] += sprintf(chunkIn[imate1] + chunkInSizeBytesTotal[imate1], " %llu %c %i", P.iReadAll, passFilterIllumina, P.readFilesIndex);
 
+                            string dummy;
                             for (int ii=3; ii<=9; ii++)
-                                P.inOut->readIn[0] >> str1; //skip fields until sequence
+                                P.inOut->readIn[0] >> dummy; //skip fields until sequence
 
                             string seq1,qual1;
                             P.inOut->readIn[0]  >> seq1 >> qual1;
-                            if (flag & 0x10) {//sequence reverse-coomplemented
+                            if (flag1 & 0x10) {//sequence reverse-coomplemented
                                 revComplementNucleotides(seq1);
                                 reverse(qual1.begin(),qual1.end());
                             };
-
-                            getline(P.inOut->readIn[0],str1); //str1 is now all SAM attributes
-                            chunkInSizeBytesTotal[imate1] += sprintf(chunkIn[imate1] + chunkInSizeBytesTotal[imate1], "%s\n%s\n+\n%s\n", str1.c_str(), seq1.c_str(), qual1.c_str());
+                            
+                            string attrs;
+                            getline(P.inOut->readIn[0], attrs); //rest of the SAM line: str1 is now all SAM attributes - it's added to the read ID line (1st "fastq" line)
+                            chunkInSizeBytesTotal[imate1] += sprintf(chunkIn[imate1] + chunkInSizeBytesTotal[imate1], "%s\n%s\n+\n%s\n", attrs.c_str(), seq1.c_str(), qual1.c_str());
                         };
                     };
+                    
+                ///////////////////////////////////////////////////////////////////////////////////// FASTQ    
                 } else if (nextChar=='@') {//fastq, not multi-line
                     P.iReadAll++; //increment read number
                     if (P.outFilterBySJoutStage!=2) {//not the 2nd stage of the 2-stage mapping, read ID from the 1st read
                         string readID;
                         P.inOut->readIn[0] >> readID;
+                        removeStringEndControl(readID);
                         if (P.outSAMreadIDnumber) {
                             readID="@"+to_string(P.iReadAll);
                         };
@@ -87,54 +122,42 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
                         if (P.inOut->readIn[0].peek()!='\n') {//2nd field exists
                             string field2;
                             P.inOut->readIn[0] >> field2;
-                            if (field2.length()>=3 && field2.at(1)==':' && field2.at(2)=='Y' && field2.at(3)==':' )
+                            if (field2.length()>=3 && field2[1]==':' && field2[2]=='Y' && field2[3]==':' )
                                 passFilterIllumina='Y';
                         };
+                        
+                        //add extra information to readID line
                         readID += ' '+ to_string(P.iReadAll)+' '+passFilterIllumina+' '+to_string(P.readFilesIndex);
 
                         //ignore the rest of the read name for both mates
-                        for (uint imate=0; imate<P.readNmatesIn; imate++)
+                        for (uint imate=0; imate<P.readNends; imate++)
                             P.inOut->readIn[imate].ignore(DEF_readNameSeqLengthMax,'\n');
 
-                        if (P.pSolo.type>0) {//record barcode sequence
-                            string seq1;
-                            getline(P.inOut->readIn[P.pSolo.barcodeRead],seq1);
-                            if (seq1.size() != P.pSolo.bL && P.pSolo.bL > 0) {
-                                ostringstream errOut;
-                                errOut << "EXITING because of FATAL ERROR in input read file: the total length of barcode sequence is "  << seq1.size() << " not equal to expected " <<P.pSolo.bL <<"\n"  ;
-                                errOut << "Read ID="<<readID<< "   Sequence="<<seq1<<"\n";
-                                errOut << "SOLUTION: make sure that the barcode read is the last file in --readFilesIn , and check that it has the correct formatting\n";
-                                errOut << "          If UMI+CB length is not equal to the barcode read length, specify barcode read length with --soloBarcodeReadLength\n";
-                                exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_INPUT_FILES, P);
-                            };
-                            readID += ' ' + seq1;
-                            P.inOut->readIn[P.pSolo.barcodeRead].ignore(DEF_readNameSeqLengthMax,'\n');//skip to the end of 3rd ("+") line
-                            getline(P.inOut->readIn[P.pSolo.barcodeRead],seq1); //read qualities
-                            readID += ' ' + seq1;
-                            g_statsAll.qualHistCalc(1, seq1.c_str(), seq1.size());
-                        };
-
                         //copy the same readID to both mates
-                        for (uint imate=0; imate<P.readNmates; imate++) {
+                        for (uint imate=0; imate<P.readNends; imate++) {
                             chunkInSizeBytesTotal[imate] += 1 + readID.copy(chunkIn[imate] + chunkInSizeBytesTotal[imate], readID.size(),0);
                             chunkIn[imate][chunkInSizeBytesTotal[imate]-1]='\n';
                         };
                     };
                     //copy 3 (4 for stage 2) lines: sequence, dummy, quality
-                    for (uint imate=0; imate<P.readNmates; imate++) {
-                        for (uint iline=(P.outFilterBySJoutStage==2 ? 0:1);iline<4;iline++) {
-                            P.inOut->readIn[imate].getline(chunkIn[imate] + chunkInSizeBytesTotal[imate], DEF_readNameSeqLengthMax+1 );
-                            chunkInSizeBytesTotal[imate] += P.inOut->readIn[imate].gcount();
-                            chunkIn[imate][chunkInSizeBytesTotal[imate]-1]='\n';
-                            
-                            if (iline==3 && P.outFilterBySJoutStage!=2) {
-                                g_statsAll.qualHistCalc(imate, chunkIn[imate] + chunkInSizeBytesTotal[imate] - P.inOut->readIn[imate].gcount(), P.inOut->readIn[imate].gcount());
-                            };
-                        };
+                    for (uint imate=0; imate<P.readNends; imate++) {
+                        // read 1st line for 2nd stage only
+                        if (P.outFilterBySJoutStage == 2)
+                            chunkInSizeBytesTotal[imate] += fastqReadOneLine(P.inOut->readIn[imate], chunkIn[imate] + chunkInSizeBytesTotal[imate]);
+                        //sequence
+                        chunkInSizeBytesTotal[imate] += fastqReadOneLine(P.inOut->readIn[imate], chunkIn[imate] + chunkInSizeBytesTotal[imate]);
+                        //skip 3rd line, record '+'
+                        P.inOut->readIn[imate].ignore(DEF_readNameSeqLengthMax, '\n');
+                        chunkIn[imate][chunkInSizeBytesTotal[imate]] = '+';
+                        chunkIn[imate][chunkInSizeBytesTotal[imate]+1] = '\n';
+                        chunkInSizeBytesTotal[imate] += 2;
+                        //quality
+                        uint64 lenIn = fastqReadOneLine(P.inOut->readIn[imate], chunkIn[imate] + chunkInSizeBytesTotal[imate]);
+                        chunkInSizeBytesTotal[imate] += lenIn;
                     };
                 } else if (nextChar=='>') {//fasta, can be multiline, which is converted to single line
                     P.iReadAll++; //increment read number
-                    for (uint imate=0; imate<P.readNmatesIn; imate++) {
+                    for (uint imate=0; imate<P.readNends; imate++) {
                         if (P.outFilterBySJoutStage!=2) {//not the 2nd stage of the 2-stage mapping
 
                             if (P.outSAMreadID=="Number") {
@@ -147,18 +170,20 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
                             P.inOut->readIn[imate].ignore(DEF_readNameSeqLengthMax,'\n');
 
                             chunkInSizeBytesTotal[imate] += sprintf(chunkIn[imate] + chunkInSizeBytesTotal[imate], " %llu %c %i \n", P.iReadAll, 'N', P.readFilesIndex);
-
-
                         };
-//                         else {//2nd stage of 2-stage mapping
-//                         read index and file index are already recorded with the read name, simply copy it
-//                         P.inOut->readIn[imate].getline(chunkIn[imate] + chunkInSizeBytesTotal[imate], DEF_readNameSeqLengthMax+1 );
-//                         };
+                        
+                        //read multi-line fasta
                         nextChar=P.inOut->readIn[imate].peek();
-                        while (nextChar!='@' && nextChar!='>' && nextChar!=' ' && nextChar!='\n' && P.inOut->readIn[imate].good()) {//read multi-line fasta
+                        while (nextChar!='@' && nextChar!='>' && nextChar!=' ' && nextChar!='\n' && P.inOut->readIn[imate].good()) {
                             P.inOut->readIn[imate].getline(chunkIn[imate] + chunkInSizeBytesTotal[imate], DEF_readSeqLengthMax + 1 );
-                            if (P.inOut->readIn[imate].gcount()<2) break; //no more input
-                            chunkInSizeBytesTotal[imate] += P.inOut->readIn[imate].gcount()-1;
+                            if (P.inOut->readIn[imate].gcount()<2) 
+                                break; //no more input
+                                
+                            chunkInSizeBytesTotal[imate] += P.inOut->readIn[imate].gcount()-1; //-1 because \n was counted, bu wee need to remove it
+                            if ( int(chunkIn[imate][chunkInSizeBytesTotal[imate]-1]) < 33 ) {//remove control char at the end if present
+                                chunkInSizeBytesTotal[imate]--;
+                            };
+                            
                             nextChar=P.inOut->readIn[imate].peek();
                         };
                         chunkIn[imate][chunkInSizeBytesTotal[imate]]='\n';
@@ -203,13 +228,14 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
                 g_threadChunks.chunkInN++;
             };
 
-            for (uint imate=0; imate<P.readNmates; imate++) chunkIn[imate][chunkInSizeBytesTotal[imate]]='\n';//extra empty line at the end of the chunks
+            for (uint imate=0; imate<P.readNends; imate++) 
+                chunkIn[imate][chunkInSizeBytesTotal[imate]]='\n';//extra empty line at the end of the chunks
 
             if (P.runThreadN>1) pthread_mutex_unlock(&g_threadChunks.mutexInRead);
 
         } else {//read from one file per thread
             noReadsLeft=true;
-            for (uint imate=0; imate<P.readNmates; imate++) {
+            for (uint imate=0; imate<P.readNends; imate++) {
                 RA->chunkOutFilterBySJoutFiles[imate].flush();
                 RA->chunkOutFilterBySJoutFiles[imate].seekg(0,ios::beg);
                 RA->readInStream[imate]=& RA->chunkOutFilterBySJoutFiles[imate];
@@ -238,7 +264,7 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
             if (P.runThreadN>1)
                 pthread_mutex_lock(&g_threadChunks.mutexOutUnmappedFastx);
 
-            for (uint ii=0;ii<P.readNmatesIn;ii++) {
+            for (uint ii=0;ii<P.readNends;ii++) {
                 chunkFstreamCat (RA->chunkOutUnmappedReadsStream[ii],P.inOut->outUnmappedReadsStream[ii], false, g_threadChunks.mutexOutUnmappedFastx);
             };
 
@@ -251,3 +277,22 @@ void ReadAlignChunk::processChunks() {//read-map-write chunks
     if (P.runThreadN>1) pthread_mutex_unlock(&g_threadChunks.mutexLogMain);
 };
 
+inline uint64 fastqReadOneLine(ifstream &streamIn, char *arrIn)
+{
+    uint64 lenIn;
+    streamIn.getline(arrIn, DEF_readNameSeqLengthMax+1 );
+    lenIn = streamIn.gcount(); //=seqLength+1: includes \0 but not \n. We will replace \0 with \n
+    
+    if ( int(arrIn[lenIn-2]) < 33 ) {//remove control char at the end if present
+        --lenIn;
+    };
+    
+    arrIn[lenIn-1]='\n'; //replace \0 with \n
+    return lenIn; //lenIn contains \n at the end
+};
+
+inline void removeStringEndControl(string &str)
+{//removes control character (including space) from the end of the string
+    if (int(str.back())<33)
+        str.pop_back();
+};
