@@ -3,7 +3,7 @@
 
 void ReadAlign::peOverlapMergeMap() {
 
-    if (!P.peOverlap.yes || P.readNmates!=2 ) {//no peOverlap
+    if (!P.peOverlap.yes || P.readNmates!=2 ) {//no peOverlap //not readNends: this is alignment
         peOv.yes=false;
         return;
     };
@@ -122,26 +122,18 @@ void ReadAlign::peMergeMates() {
     readLength[1]=0;
     readLengthOriginal[0]=Lread;
     readLengthOriginal[1]=0;
-    readNmates=1;
+    readNmates=1; //not readNends: this is alignment
 
     //fill Read1[1,2]
     complementSeqNumbers(Read1[0],Read1[1],Lread); //returns complement of Reads[ii]
     for (uint ii=0;ii<Lread;ii++) {//reverse
         Read1[2][Lread-ii-1]=Read1[1][ii];
-        if (Read1[1][ii]<4) {
-            Qual1[0][ii]=1;
-            Qual1[1][Lread-ii-1]=1;
-        } else {
-            Qual1[0][ii]=0;
-            Qual1[1][Lread-ii-1]=0;
-        };
-
     };
 
     return;
 };
 
-void Transcript::peOverlapSEtoPE(uint* mateStart, Transcript &t) {//convert alignment from merged-SE to PE
+void Transcript::peOverlapSEtoPE(uint* mateStart, const Transcript &t) {//convert alignment from merged-SE to PE
 
     uint mLen[2];
     mLen[0]=readLength[t.Str];
@@ -222,6 +214,11 @@ void Transcript::peOverlapSEtoPE(uint* mateStart, Transcript &t) {//convert alig
             };
 
             ++nExons;
+            if (nExons>MAX_N_EXONS) {//cannot transform this alignment to PE, too many exons
+                maxScore=0;
+                nExons=0;
+                return;
+            };
         };
         canonSJ[nExons-1]=-3; //marks "junction" between mates
         sjAnnot[nExons-1]=0;
@@ -268,28 +265,97 @@ void Transcript::peOverlapSEtoPE(uint* mateStart, Transcript &t) {//convert alig
 
 void ReadAlign::peOverlapSEtoPE(ReadAlign &seRA) {//ReAdAlign: convert SE to PE and copy
 
-    nW=seRA.nW;
-    memcpy((void*) nWinTr, (void*) seRA.nWinTr, nW*sizeof(*nWinTr));
+    //nW=seRA.nW;
+    //memcpy((void*) nWinTr, (void*) seRA.nWinTr, nW*sizeof(*nWinTr));
 
     uint trNtotal=0;
     intScore bestScore=-10*Lread;
     trBest=trArray;//just to initialize - to the 0th spot in the trArray
-    for (uint iW=0; iW<nW; iW++) {//scan windows
-        trAll[iW]=trArrayPointer+trNtotal;
-        for (uint iTr=0; iTr<nWinTr[iW]; iTr++) {//scan transcripts
-            ++trNtotal;
-            *trAll[iW][iTr]=*trInit;
-            trAll[iW][iTr]->peOverlapSEtoPE(peOv.mateStart, *seRA.trAll[iW][iTr]);
-            trAll[iW][iTr]->alignScore(Read1,mapGen.G,P);
-            if (trAll[iW][iTr]->maxScore > trAll[iW][0]->maxScore) {
-                swap(trAll[iW][iTr],trAll[iW][0]);
+    
+    uint64 iW1=0;
+    for (uint iW=0; iW<seRA.nW; iW++) {//scan windows
+        trAll[iW1]=trArrayPointer+trNtotal;
+        uint64 iTr1=0;
+        for (uint iTr=0; iTr<seRA.nWinTr[iW]; iTr++) {//scan transcripts
+            *trAll[iW1][iTr1]=*trInit;
+            
+            trAll[iW1][iTr1]->peOverlapSEtoPE(peOv.mateStart, *seRA.trAll[iW][iTr]);
+            if (trAll[iW1][iTr1]->nExons==0)
+                continue; //conversion did not work
+            
+            trAll[iW1][iTr1]->alignScore(Read1,mapGen.G,P);
+            if (trAll[iW1][iTr1]->maxScore > trAll[iW1][0]->maxScore) {
+                swap(trAll[iW][iTr1],trAll[iW][0]);
             };
+            
+            ++iTr1;
+            ++trNtotal;            
         };
-        if (trAll[iW][0]->maxScore>bestScore) {
-            trBest=trAll[iW][0];
-            bestScore=trBest->maxScore;
+        if (iTr1>0) {//if conversion worked for at least one align
+            nWinTr[iW1]=iTr1;
+            if (trAll[iW1][0]->maxScore > bestScore) {
+                trBest=trAll[iW1][0];
+                bestScore=trBest->maxScore;
+            };            
+            ++iW1;
         };
     };
 
+    nW=iW1;
     return;
 };
+
+void ReadAlign::peOverlapChimericSEtoPE(const Transcript *seTrIn1, const Transcript *seTrIn2, Transcript *peTrOut1, Transcript *peTrOut2) {
+
+    //convert merged into PE
+    Transcript tempTrChim[2];
+    tempTrChim[0]=*trInit;
+    tempTrChim[1]=*trInit;
+    tempTrChim[0].peOverlapSEtoPE(peOv.mateStart,*seTrIn1);
+    tempTrChim[1].peOverlapSEtoPE(peOv.mateStart,*seTrIn2);
+
+    uint segLen[2][2]; //segment length [tempTrChim][mate]
+    uint segEx[2];//last exon of the mate0 [tempTrChim]
+    uint segLmin=-1LLU, i1=0,i2=0;
+    for (uint ii=0; ii<2; ii++) {
+        segLen[ii][0]=0;
+        segLen[ii][1]=0;
+        for (uint iex=0; iex<tempTrChim[ii].nExons; iex++) {
+            if (tempTrChim[ii].exons[iex][EX_iFrag]==tempTrChim[ii].exons[0][EX_iFrag]) {
+                segLen[ii][0]+=tempTrChim[ii].exons[iex][EX_L];
+                segEx[ii]=iex;
+            } else {
+                segLen[ii][1]+=tempTrChim[ii].exons[iex][EX_L];
+            };
+        };
+        for (uint jj=0; jj<2; jj++) {
+            if (segLen[ii][jj]<segLmin || (segLen[ii][jj]==segLmin && tempTrChim[ii].exons[0][EX_G]>tempTrChim[ii-1].exons[0][EX_G])) {
+                segLmin=segLen[ii][jj];
+                i1=ii;//tempTrChim of the shortest segment length
+                i2=jj;//mate of the shortest segment length
+            };
+        };
+    };
+
+    if (i2==1) {//eliminate mate1: simply cut the exons that belong to mate1
+        tempTrChim[i1].nExons=segEx[i1]+1;
+    } else {//eliminate mate 0: shift mate1 exon to the beginning
+        for (uint iex=0; iex<tempTrChim[i1].nExons; iex++) {
+            uint iex1=iex+segEx[i1]+1;
+            for (uint ii=0; ii<EX_SIZE; ii++) {
+                tempTrChim[i1].exons[iex][ii]=tempTrChim[i1].exons[iex1][ii];
+            };
+            tempTrChim[i1].canonSJ[iex]=tempTrChim[i1].canonSJ[iex1];
+            tempTrChim[i1].sjAnnot[iex]=tempTrChim[i1].sjAnnot[iex1];
+            tempTrChim[i1].sjStr[iex]=tempTrChim[i1].sjStr[iex1];
+            tempTrChim[i1].shiftSJ[iex][0]=tempTrChim[i1].shiftSJ[iex1][0];
+            tempTrChim[i1].shiftSJ[iex][1]=tempTrChim[i1].shiftSJ[iex1][1];
+        };
+        tempTrChim[i1].nExons=tempTrChim[i1].nExons-segEx[i1]-1;
+    };
+
+    *peTrOut1=tempTrChim[0];
+    *peTrOut2=tempTrChim[1];
+    return;
+};
+
