@@ -1,4 +1,5 @@
 #include "SequenceFuns.h"
+#include <assert.h>  
 
 void complementSeqNumbers(char* ReadsIn, char* ReadsOut, uint Lread) {//complement the numeric sequences
     for (uint jj=0;jj<Lread;jj++) {
@@ -144,6 +145,28 @@ void convertNucleotidesToNumbers(const char* R0, char* R1, const uint Lread) {//
                 };
 };
 
+void convertCapitalBasesToNum(uint8_t *rS, uint64_t N)
+{//only capital bases are allowed
+    for (uint64_t ib=0; ib<N; ib++) {
+        switch (rS[ib]) {
+            case 'A':
+                rS[ib]=0;
+                break;
+            case 'C':
+                rS[ib]=1;
+                break;        
+            case 'G':
+                rS[ib]=2;
+                break;   
+            case 'T':
+                rS[ib]=3;
+                break;   
+            default:
+                rS[ib]=4;
+        };
+    };
+};
+
 uint convertNucleotidesToNumbersRemoveControls(const char* R0, char* R1, const uint Lread) {//transform sequence  from ACGT into 0-1-2-3 code
     uint iR1=0;
     for (uint jj=0;jj<Lread;jj++) {
@@ -318,11 +341,15 @@ uint localSearchNisMM(const char *x, uint nx, const char *y, uint ny, double pMM
 uint32 localAlignHammingDist(const string &text, const string &query, uint32 &pos)
 {
     uint32 distBest=query.size();
+    if (text.size()<query.size()) {//query is longer than text, no match
+    	return text.size()+1;
+    };
     for (uint32 ii=0; ii<text.size()-query.size()+1; ii++) {
         uint32 dist1=0;
         for (uint32 jj=0; jj<query.size(); jj++) {
-            if (text[jj+ii]!=query[jj])
+            if (query[jj]!='N' && text[jj+ii]!=query[jj]) {//N in query does not count as mismatch
                 ++dist1;
+            };
         };
         if (dist1<distBest) {
             distBest=dist1;
@@ -332,14 +359,64 @@ uint32 localAlignHammingDist(const string &text, const string &query, uint32 &po
     return distBest;
 };
 
-uint qualitySplit(char* r, char* q, uint L, char Qsplit, uint maxNsplit, uint  minLsplit, uint** splitR) {
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+/*
+uint32 localSearchGeneral(const char *text, const uint32 textLen, const vector<char> &query, const int32 textStart, const int32 textEnd, double pMM, vector <uint32> vecMM, uint32 &nMM)
+{
+    assert(textEnd <= (int32)textLen);
+    assert(textStart + (int32)query.size() >= 0);
+
+    nMM=0;
+    
+    uint32 nMatchBest=0;
+    int32 posBest=textLen;
+    uint32 clippedL = 0;
+
+    
+    int32 dirSearch = (textStart <= textEnd ? 1 : -1); //search direction
+    
+    for (int32 pos=textStart; pos!=textEnd; pos+=dirSearch) {
+        int32 qs = max(0, -pos);
+        int32 qe = min((uint32)query.size(), (uint32)(textLen-pos) );
+                       
+        uint32 nMatch1=0, nMM1=0;
+
+        for (uint32 iq=qs; iq<qe; iq++) {
+            if (text[pos+iq]>3) 
+                continue; //Ns in the text are not counted as matches or mismatches
+            if (text[pos+iq]==query[iq]) {
+                nMatch1++;
+            } else {
+                nMM1++;
+                if ( nMM1 >= vecMM.size() ) {
+                    nMatch1=0;
+                    break; //too many mismatches
+                };
+            };
+        };
+        
+        //if ( (nMatch1>nMatchBest || (nMatch1==nMatchBest && nMM1<nMM)) && double(nMM1)<=double(nMatch1)*pMM ) {
+        if ( (nMatch1>nMatchBest || (nMatch1==nMatchBest && nMM1<nMM)) && nMM1<vecMM.size() && (qe-qs)>=vecMM[nMM1]) {
+            posBest=pos;
+            nMatchBest=nMatch1;
+            nMM=nMM1;
+            clippedL = (uint32)(textStart <= textEnd ? posBest+(int32)query.size(): -posBest+(int32)textLen );
+        };        
+    };
+        
+    return clippedL;
+};
+*/
+///////////////////////////////////////////////////////////////////////////////////////////////////////////////
+uint qualitySplit(char* r,uint L, uint maxNsplit, uint  minLsplit, uint** splitR) {
     //splits the read r[L] by quality scores q[L], outputs in splitR - split coordinate/length - per base
     //returns number of good split regions
     uint iR=0,iS=0,iR1,LgoodMin=0, iFrag=0;
     while ( (iR<L) & (iS<maxNsplit) ) { //main cycle
         //find next good base
-        while ( (iR<L) && ( (q[iR]<Qsplit) || (r[iR]>3) ) ) {
-            if (r[iR]==MARK_FRAG_SPACER_BASE) iFrag++; //count read fragments
+        while ( iR<L && r[iR]>3 ) {
+            if (r[iR]==MARK_FRAG_SPACER_BASE) 
+                iFrag++; //count read fragments
             iR++;
         };
 
@@ -348,7 +425,7 @@ uint qualitySplit(char* r, char* q, uint L, char Qsplit, uint maxNsplit, uint  m
         iR1=iR;
 
         //find the next bad base
-        while ( iR<L && q[iR]>=Qsplit && r[iR]<=3 ) {
+        while ( iR<L && r[iR]<=3 ) {
             iR++;
         };
 
