@@ -13,15 +13,16 @@ SoloReadFeature::SoloReadFeature(int32 feTy, Parameters &Pin, int iChunk)
     readInfoYes=pSolo.readInfoYes[featureType];
     
     if (pSolo.cbWLyes) {
-        cbReadCount = new uint32[pSolo.cbWLsize];
-        for (uint32 ii=0; ii<pSolo.cbWLsize; ii++) {
-            cbReadCount[ii]=0;
-        };
+        cbReadCount.resize(pSolo.cbWLsize,0);
     };
 
     if (iChunk>=0) {
-        streamReads = &fstrOpen(P.outFileTmp+"/solo"+SoloFeatureTypes::Names[featureType]+'_'+std::to_string(iChunk),ERROR_OUT, P);
-    };    
+        //open with flagDelete=false, i.e. try to keep file if it exists
+        streamReads = &fstrOpen(P.outFileTmp+"/solo"+SoloFeatureTypes::Names[featureType]+'_'+std::to_string(iChunk), ERROR_OUT, P, false);
+    };
+    
+    if (featureType==SoloFeatureTypes::Transcript3p)
+        transcriptDistCount.resize(10000,0);
 };
 
 void SoloReadFeature::addCounts(const SoloReadFeature &rfIn)
@@ -35,6 +36,11 @@ void SoloReadFeature::addCounts(const SoloReadFeature &rfIn)
             cbReadCountMap[ii->first] += ii->second;
         };
     };
+    
+    if (transcriptDistCount.size()>0) {
+        for (uint32 ii=0; ii<transcriptDistCount.size(); ii++)
+            transcriptDistCount[ii] += rfIn.transcriptDistCount[ii];
+    };
 };
 
 void SoloReadFeature::addStats(const SoloReadFeature &rfIn)
