@@ -17,9 +17,11 @@ public:
 
     uint32 homoPolymer[4];//homopolymer constants
 
-    uint32 *cbReadCount;
+    vector<uint32> cbReadCount;
     map <uint32,uint32> cbReadCountMap;
     
+    vector<uint32> transcriptDistCount;
+    
     bool readInfoYes;
 
     fstream *streamReads;
@@ -29,12 +31,11 @@ public:
     SoloReadFeatureStats stats;
 
     SoloReadFeature (int32 feTy, Parameters &Pin, int iChunk);
-    void record(SoloReadBarcode &soloBar, uint nTr, Transcript *alignOut, uint64 iRead, ReadAnnotations &readAnnot);
+    void record(SoloReadBarcode &soloBar, uint nTr, Transcript **alignOut, uint64 iRead, ReadAnnotations &readAnnot);
     void addCounts(const SoloReadFeature &soloCBin);
     void addStats(const SoloReadFeature &soloCBin);
     void statsOut(ofstream &streamOut);
-    void inputRecords(uint32 **cbP, uint32 cbPstride, uint32 *cbReadCountExact, 
-                      ofstream *streamTranscriptsOut, vector<readInfoStruct> &readInfo, SoloFeature **soloFeatAll);
+    void inputRecords(uint32 **cbP, uint32 cbPstride, vector<uint32> &cbReadCountTotal, vector<readInfoStruct> &readInfo);
 
 private:
     const int32 featureType;
