@@ -1,6 +1,6 @@
 #include "SoloRead.h"
 
-void SoloRead::record(uint64 nTr, Transcript *alignOut, uint64 iRead, ReadAnnotations &readAnnot)
+void SoloRead::record(uint64 nTr, Transcript **alignOut, uint64 iRead, ReadAnnotations &readAnnot)
 {
     if (pSolo.type==pSolo.SoloTypes::None)
         return;
