@@ -11,8 +11,6 @@ void Stats::resetN() {//zero all counters
     for (uint ii=0; ii<SJ_MOTIF_SIZE; ii++) {
         splicesN[ii]=0;
     };
-
-    qualHist={{}};
 };
 
 Stats::Stats() {//constructor
@@ -41,6 +39,9 @@ void Stats::transcriptStats(Transcript &T, uint Lread) {
     mappedInsL += T.lIns;
     mappedDelL += T.lDel;
 
+    if (T.nExons==0)
+        return;
+    
     uint mappedL=0;
     for (uint ii=0; ii<T.nExons; ii++) {
         mappedL += T.exons[ii][EX_L];
@@ -153,10 +154,3 @@ void Stats::writeLines(ofstream &streamOut, const vector<int> outType, const str
     };
 };
 
-void Stats::qualHistCalc(const uint64 imate, const char* qual, const uint64 len)
-{//calculates histogram of quality scores for each imate        
-    for (uint64 ix=0; ix<len; ix++) {
-            qualHist[imate][(uint8)qual[ix]]++;
-    };
-};
-
