@@ -24,9 +24,6 @@ class Stats {
         uint chimericAll;
 
         time_t timeStart, timeStartMap, timeFinishMap, timeLastReport, timeFinish;
-
-        //quality
-        array<array<uint64,256>,2> qualHist;
         
         Stats ();
         void resetN();
@@ -39,5 +36,6 @@ class Stats {
         void writeLines(ofstream &streamOut, const vector<int> outType, const string commStr, const string outStr);// write commented lines to text files with stats
         
         void qualHistCalc(const uint64 imate, const char* qual, const uint64 len);
+        //void qualHistCalcSolo(const uint64 imate, const char* qual, const vector<uint32> stlen);
 };
 #endif
